@@ -63,7 +63,33 @@ def run_pipeline(config, start_module_name):
         sample_replicates=config.replicates,
         samples_to_exclude=config.samples_to_exclude,
         markers_to_exclude=config.markers_to_exclude,
-        modules=components.pipeline_module_names,
+        view_sample=config.view_sample,
+        delint_mode=config.delint_mode,
+        show_ab_channels=config.show_ab_channels,
+        log_ratio_rnge=config.log_ratio_rnge,
+        hexbins=config.hexbins,
+        hexbin_grid_size=config.hexbin_grid_size,
+        channel_exclusions=config.channel_exclusions,
+        numPCAComponents=config.numPCAComponents,
+        pointSize=config.pointSize,
+        normalize=config.normalize,
+        labelPoints=config.labelPoints,
+        condHueDict=config.condHueDict,
+        fracForEmbedding=config.fracForEmbedding,
+        numTSNEComponents=config.numTSNEComponents,
+        perplexity=config.perplexity,
+        earlyExaggeration=config.earlyExaggeration,
+        learningRate=config.learningRate,
+        metric=config.metric,
+        random_state=config.random_state,
+        denominator_cluster=config.denominator_cluster,
+        FDRCorrection=config.FDRCorrection,
+        bonferroniCorrection=config.bonferroniCorrection,
+        numThumbnails=config.numThumbnails,
+        cropDict=config.cropDict,
+        spatialDict1=config.spatialDict1,
+        spatialDict2=config.spatialDict2,
+        radiusRange=config.radiusRange,
         )
 
     # start_idx = module_order[start_index:]
